@@ -39,9 +39,12 @@ class TransformClient(NamespacedClient):
         timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Delete a transform. Deletes a transform.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/delete-transform.html>`_
+          <p>Delete a transform.</p>
+
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/v9/operation/operation-transform-delete-transform>`_
 
         :param transform_id: Identifier for the transform.
         :param delete_dest_index: If this value is true, the destination index is deleted
@@ -99,9 +102,13 @@ class TransformClient(NamespacedClient):
         size: t.Optional[int] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Get transforms. Retrieves configuration information for transforms.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/get-transform.html>`_
+          <p>Get transforms.
+          Get configuration information for transforms.</p>
+
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/v9/operation/operation-transform-get-transform>`_
 
         :param transform_id: Identifier for the transform. It can be a transform identifier
             or a wildcard expression. You can get information for all transforms by using
@@ -168,9 +175,13 @@ class TransformClient(NamespacedClient):
         timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Get transform stats. Retrieves usage information for transforms.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/get-transform-stats.html>`_
+          <p>Get transform stats.</p>
+          <p>Get usage information for transforms.</p>
+
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/v9/operation/operation-transform-get-transform-stats>`_
 
         :param transform_id: Identifier for the transform. It can be a transform identifier
             or a wildcard expression. You can get information for all transforms by using
@@ -249,14 +260,16 @@ class TransformClient(NamespacedClient):
         body: t.Optional[t.Dict[str, t.Any]] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Preview a transform. Generates a preview of the results that you will get when
-        you create a transform with the same configuration. It returns a maximum of 100
-        results. The calculations are based on all the current data in the source index.
-        It also generates a list of mappings and settings for the destination index.
-        These values are determined based on the field types of the source index and
-        the transform aggregations.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/preview-transform.html>`_
+          <p>Preview a transform.
+          Generates a preview of the results that you will get when you create a transform with the same configuration.</p>
+          <p>It returns a maximum of 100 results. The calculations are based on all the current data in the source index. It also
+          generates a list of mappings and settings for the destination index. These values are determined based on the field
+          types of the source index and the transform aggregations.</p>
+
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/v9/operation/operation-transform-preview-transform>`_
 
         :param transform_id: Identifier for the transform to preview. If you specify
             this path parameter, you cannot provide transform configuration details in
@@ -371,29 +384,29 @@ class TransformClient(NamespacedClient):
         body: t.Optional[t.Dict[str, t.Any]] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Create a transform. Creates a transform. A transform copies data from source
-        indices, transforms it, and persists it into an entity-centric destination index.
-        You can also think of the destination index as a two-dimensional tabular data
-        structure (known as a data frame). The ID for each document in the data frame
-        is generated from a hash of the entity, so there is a unique row per entity.
-        You must choose either the latest or pivot method for your transform; you cannot
-        use both in a single transform. If you choose to use the pivot method for your
-        transform, the entities are defined by the set of `group_by` fields in the pivot
-        object. If you choose to use the latest method, the entities are defined by the
-        `unique_key` field values in the latest object. You must have `create_index`,
-        `index`, and `read` privileges on the destination index and `read` and `view_index_metadata`
-        privileges on the source indices. When Elasticsearch security features are enabled,
-        the transform remembers which roles the user that created it had at the time
-        of creation and uses those same roles. If those roles do not have the required
-        privileges on the source and destination indices, the transform fails when it
-        attempts unauthorized operations. NOTE: You must use Kibana or this API to create
-        a transform. Do not add a transform directly into any `.transform-internal*`
-        indices using the Elasticsearch index API. If Elasticsearch security features
-        are enabled, do not give users any privileges on `.transform-internal*` indices.
-        If you used transforms prior to 7.5, also do not give users any privileges on
-        `.data-frame-internal*` indices.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/put-transform.html>`_
+          <p>Create a transform.
+          Creates a transform.</p>
+          <p>A transform copies data from source indices, transforms it, and persists it into an entity-centric destination index. You can also think of the destination index as a two-dimensional tabular data structure (known as
+          a data frame). The ID for each document in the data frame is generated from a hash of the entity, so there is a
+          unique row per entity.</p>
+          <p>You must choose either the latest or pivot method for your transform; you cannot use both in a single transform. If
+          you choose to use the pivot method for your transform, the entities are defined by the set of <code>group_by</code> fields in
+          the pivot object. If you choose to use the latest method, the entities are defined by the <code>unique_key</code> field values
+          in the latest object.</p>
+          <p>You must have <code>create_index</code>, <code>index</code>, and <code>read</code> privileges on the destination index and <code>read</code> and
+          <code>view_index_metadata</code> privileges on the source indices. When Elasticsearch security features are enabled, the
+          transform remembers which roles the user that created it had at the time of creation and uses those same roles. If
+          those roles do not have the required privileges on the source and destination indices, the transform fails when it
+          attempts unauthorized operations.</p>
+          <p>NOTE: You must use Kibana or this API to create a transform. Do not add a transform directly into any
+          <code>.transform-internal*</code> indices using the Elasticsearch index API. If Elasticsearch security features are enabled, do
+          not give users any privileges on <code>.transform-internal*</code> indices. If you used transforms prior to 7.5, also do not
+          give users any privileges on <code>.data-frame-internal*</code> indices.</p>
+
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/v9/operation/operation-transform-put-transform>`_
 
         :param transform_id: Identifier for the transform. This identifier can contain
             lowercase alphanumeric characters (a-z and 0-9), hyphens, and underscores.
@@ -489,13 +502,17 @@ class TransformClient(NamespacedClient):
         force: t.Optional[bool] = None,
         human: t.Optional[bool] = None,
         pretty: t.Optional[bool] = None,
+        timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Reset a transform. Resets a transform. Before you can reset it, you must stop
-        it; alternatively, use the `force` query parameter. If the destination index
-        was created by the transform, it is deleted.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/reset-transform.html>`_
+          <p>Reset a transform.</p>
+          <p>Before you can reset it, you must stop it; alternatively, use the <code>force</code> query parameter.
+          If the destination index was created by the transform, it is deleted.</p>
+
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/v9/operation/operation-transform-reset-transform>`_
 
         :param transform_id: Identifier for the transform. This identifier can contain
             lowercase alphanumeric characters (a-z and 0-9), hyphens, and underscores.
@@ -503,6 +520,8 @@ class TransformClient(NamespacedClient):
         :param force: If this value is `true`, the transform is reset regardless of its
             current state. If it's `false`, the transform must be stopped before it can
             be reset.
+        :param timeout: Period to wait for a response. If no response is received before
+            the timeout expires, the request fails and returns an error.
         """
         if transform_id in SKIP_IN_PATH:
             raise ValueError("Empty value passed for parameter 'transform_id'")
@@ -519,6 +538,8 @@ class TransformClient(NamespacedClient):
             __query["human"] = human
         if pretty is not None:
             __query["pretty"] = pretty
+        if timeout is not None:
+            __query["timeout"] = timeout
         __headers = {"accept": "application/json"}
         return self.perform_request(  # type: ignore[return-value]
             "POST",
@@ -541,13 +562,17 @@ class TransformClient(NamespacedClient):
         timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Schedule a transform to start now. Instantly runs a transform to process data.
-        If you _schedule_now a transform, it will process the new data instantly, without
-        waiting for the configured frequency interval. After _schedule_now API is called,
-        the transform will be processed again at now + frequency unless _schedule_now
-        API is called again in the meantime.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/schedule-now-transform.html>`_
+          <p>Schedule a transform to start now.</p>
+          <p>Instantly run a transform to process data.
+          If you run this API, the transform will process the new data instantly,
+          without waiting for the configured frequency interval. After the API is called,
+          the transform will be processed again at <code>now + frequency</code> unless the API
+          is called again in the meantime.</p>
+
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/v9/operation/operation-transform-schedule-now-transform>`_
 
         :param transform_id: Identifier for the transform.
         :param timeout: Controls the time to wait for the scheduling to take place
@@ -592,26 +617,25 @@ class TransformClient(NamespacedClient):
         timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Start a transform. Starts a transform. When you start a transform, it creates
-        the destination index if it does not already exist. The `number_of_shards` is
-        set to `1` and the `auto_expand_replicas` is set to `0-1`. If it is a pivot transform,
-        it deduces the mapping definitions for the destination index from the source
-        indices and the transform aggregations. If fields in the destination index are
-        derived from scripts (as in the case of `scripted_metric` or `bucket_script`
-        aggregations), the transform uses dynamic mappings unless an index template exists.
-        If it is a latest transform, it does not deduce mapping definitions; it uses
-        dynamic mappings. To use explicit mappings, create the destination index before
-        you start the transform. Alternatively, you can create an index template, though
-        it does not affect the deduced mappings in a pivot transform. When the transform
-        starts, a series of validations occur to ensure its success. If you deferred
-        validation when you created the transform, they occur when you start the transform—​with
-        the exception of privilege checks. When Elasticsearch security features are enabled,
-        the transform remembers which roles the user that created it had at the time
-        of creation and uses those same roles. If those roles do not have the required
-        privileges on the source and destination indices, the transform fails when it
-        attempts unauthorized operations.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/start-transform.html>`_
+          <p>Start a transform.</p>
+          <p>When you start a transform, it creates the destination index if it does not already exist. The <code>number_of_shards</code> is
+          set to <code>1</code> and the <code>auto_expand_replicas</code> is set to <code>0-1</code>. If it is a pivot transform, it deduces the mapping
+          definitions for the destination index from the source indices and the transform aggregations. If fields in the
+          destination index are derived from scripts (as in the case of <code>scripted_metric</code> or <code>bucket_script</code> aggregations),
+          the transform uses dynamic mappings unless an index template exists. If it is a latest transform, it does not deduce
+          mapping definitions; it uses dynamic mappings. To use explicit mappings, create the destination index before you
+          start the transform. Alternatively, you can create an index template, though it does not affect the deduced mappings
+          in a pivot transform.</p>
+          <p>When the transform starts, a series of validations occur to ensure its success. If you deferred validation when you
+          created the transform, they occur when you start the transform—​with the exception of privilege checks. When
+          Elasticsearch security features are enabled, the transform remembers which roles the user that created it had at the
+          time of creation and uses those same roles. If those roles do not have the required privileges on the source and
+          destination indices, the transform fails when it attempts unauthorized operations.</p>
+
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/v9/operation/operation-transform-start-transform>`_
 
         :param transform_id: Identifier for the transform.
         :param from_: Restricts the set of transformed entities to those changed after
@@ -663,9 +687,13 @@ class TransformClient(NamespacedClient):
         wait_for_completion: t.Optional[bool] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Stop transforms. Stops one or more transforms.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/stop-transform.html>`_
+          <p>Stop transforms.
+          Stops one or more transforms.</p>
+
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/v9/operation/operation-transform-stop-transform>`_
 
         :param transform_id: Identifier for the transform. To stop multiple transforms,
             use a comma-separated list or a wildcard expression. To stop all transforms,
@@ -756,16 +784,18 @@ class TransformClient(NamespacedClient):
         body: t.Optional[t.Dict[str, t.Any]] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Update a transform. Updates certain properties of a transform. All updated properties
-        except `description` do not take effect until after the transform starts the
-        next checkpoint, thus there is data consistency in each checkpoint. To use this
-        API, you must have `read` and `view_index_metadata` privileges for the source
-        indices. You must also have `index` and `read` privileges for the destination
-        index. When Elasticsearch security features are enabled, the transform remembers
-        which roles the user who updated it had at the time of update and runs with those
-        privileges.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/update-transform.html>`_
+          <p>Update a transform.
+          Updates certain properties of a transform.</p>
+          <p>All updated properties except <code>description</code> do not take effect until after the transform starts the next checkpoint,
+          thus there is data consistency in each checkpoint. To use this API, you must have <code>read</code> and <code>view_index_metadata</code>
+          privileges for the source indices. You must also have <code>index</code> and <code>read</code> privileges for the destination index. When
+          Elasticsearch security features are enabled, the transform remembers which roles the user who updated it had at the
+          time of update and runs with those privileges.</p>
+
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/v9/operation/operation-transform-update-transform>`_
 
         :param transform_id: Identifier for the transform.
         :param defer_validation: When true, deferrable validations are not run. This
@@ -844,22 +874,23 @@ class TransformClient(NamespacedClient):
         timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Upgrade all transforms. Transforms are compatible across minor versions and between
-        supported major versions. However, over time, the format of transform configuration
-        information may change. This API identifies transforms that have a legacy configuration
-        format and upgrades them to the latest version. It also cleans up the internal
-        data structures that store the transform state and checkpoints. The upgrade does
-        not affect the source and destination indices. The upgrade also does not affect
-        the roles that transforms use when Elasticsearch security features are enabled;
-        the role used to read source data and write to the destination index remains
-        unchanged. If a transform upgrade step fails, the upgrade stops and an error
-        is returned about the underlying issue. Resolve the issue then re-run the process
-        again. A summary is returned when the upgrade is finished. To ensure continuous
-        transforms remain running during a major version upgrade of the cluster – for
-        example, from 7.16 to 8.0 – it is recommended to upgrade transforms before upgrading
-        the cluster. You may want to perform a recent cluster backup prior to the upgrade.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/upgrade-transforms.html>`_
+          <p>Upgrade all transforms.</p>
+          <p>Transforms are compatible across minor versions and between supported major versions.
+          However, over time, the format of transform configuration information may change.
+          This API identifies transforms that have a legacy configuration format and upgrades them to the latest version.
+          It also cleans up the internal data structures that store the transform state and checkpoints.
+          The upgrade does not affect the source and destination indices.
+          The upgrade also does not affect the roles that transforms use when Elasticsearch security features are enabled; the role used to read source data and write to the destination index remains unchanged.</p>
+          <p>If a transform upgrade step fails, the upgrade stops and an error is returned about the underlying issue.
+          Resolve the issue then re-run the process again.
+          A summary is returned when the upgrade is finished.</p>
+          <p>To ensure continuous transforms remain running during a major version upgrade of the cluster – for example, from 7.16 to 8.0 – it is recommended to upgrade transforms before upgrading the cluster.
+          You may want to perform a recent cluster backup prior to the upgrade.</p>
+
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/v9/operation/operation-transform-upgrade-transforms>`_
 
         :param dry_run: When true, the request checks for updates but does not run them.
         :param timeout: Period to wait for a response. If no response is received before
